@@ -63,12 +63,16 @@ def commit(repo, commit_message="", dummy=False):
                 ["git", "commit", "--allow-empty", "-m", commit_message],
                 cwd=_get_path(repo),
                 check=True,
+                stdout=subprocess.DEVNULL,
+                stderr=subprocess.DEVNULL,
             )
         else:
             subprocess.run(
                 ["git", "commit", "-am", commit_message],
                 cwd=_get_path(repo),
                 check=True,
+                stdout=subprocess.DEVNULL,
+                stderr=subprocess.DEVNULL,
             )
     except (CalledProcessError) as e:
         logger.error(f"Errore eseguendo il comando: {e}")
@@ -86,15 +90,22 @@ def add(repo):
 
 
 def push(repo, branch, remote="origin"):
-    try:
-        subprocess.run(["git", "push", remote, branch], cwd=_get_path(repo), check=True)
-    except (CalledProcessError) as e:
-        logger.error(f"Errore eseguendo il comando: {e}")
-        sys.exit(-1)
+    with Halo(text=f"Pushing {repo}...", spinner="dots", color="magenta"):
+        try:
+            subprocess.run(
+                ["git", "push", remote, branch],
+                cwd=_get_path(repo),
+                check=True,
+                stdout=subprocess.DEVNULL,
+                stderr=subprocess.DEVNULL,
+            )
+        except (CalledProcessError) as e:
+            logger.error(f"Errore eseguendo il comando: {e}")
+            sys.exit(-1)
 
 
 def pull(repo, rebase=False):
-    with Halo(text="Pulling...", spinner="dots", color="magenta"):
+    with Halo(text=f"Pulling {repo}...", spinner="dots", color="magenta"):
         try:
             if rebase:
                 subprocess.run(
@@ -118,7 +129,7 @@ def pull(repo, rebase=False):
 
 
 def fetch(repo, remote="origin"):
-    with Halo(text="Fetching...", spinner="dots", color="magenta"):
+    with Halo(text=f"Fetching {repo}...", spinner="dots", color="magenta"):
         try:
             subprocess.run(
                 ["git", "fetch", "--quiet"],
@@ -220,10 +231,11 @@ def local_branch_exists(repo, branch):
         return False
 
 
-def current_branch_name():
+def current_branch_name(repo):
     try:
         output = subprocess.run(
             ["git", "rev-parse", "--abbrev-ref", "HEAD"],
+            cwd=_get_path(repo),
             stdout=subprocess.PIPE,
             check=True,
         ).stdout.decode("utf-8")
@@ -235,13 +247,28 @@ def current_branch_name():
 
 def is_dirty(repo):
     try:
-        subprocess.run(["git", "diff", "--quiet"], check=True)
-        subprocess.run(["git", "diff", "HEAD", "--name-only", "--quiet"], check=True)
-        return False
-    except CalledProcessError:
-        logger.error(
-            f"Hai modifiche non committate su {repo} oppure non è un repository!"
+        output = subprocess.run(
+            ["git", "status", "--porcelain"],
+            cwd=_get_path(repo),
+            check=True,
+            stdout=subprocess.PIPE,
+        ).stdout.decode("utf-8")
+
+        return len(output) != 0
+    except (CalledProcessError) as e:
+        logger.error(f"Errore eseguendo il comando: {e}")
+        sys.exit(-1)
+
+
+def reset(repo):
+    try:
+        subprocess.run(
+            ["git", "reset", "HEAD", "--hard", "--quiet"],
+            cwd=_get_path(repo),
+            check=True,
         )
+    except CalledProcessError as e:
+        logger.error(f"Errore eseguendo git reset su {repo}: {e}")
         sys.exit(-1)
 
 
